@@ -615,3 +615,213 @@ sub init_child {
 __END__
 
 # put POD here
+=head1 NAME
+
+Forks::Super::Job - object representing a background task
+
+=head1 VERSION
+
+0.21
+
+=head1 SYNOPSIS
+
+    use Forks::Super;
+
+    $pid = Forks::Super::fork( \%options );  # see Forks::Super
+    $job = Forks::Super::Job::get($pid);
+    $job = Forks::Super::Job::getByName($name);
+    print "Current job state is $job->{state}\n";
+    print "Job was created at ", scalar localtime($job->{created}), "\n";
+
+=head1 DESCRIPTION
+
+Calls to C<Forks::Super::fork> that successfully spawn a child process or
+create a L<deferred job|Forks#Deferred jobs> will cause a C<Forks::Super::Job>
+instance to be created to track the job's state. For many uses of
+C<fork>, it will not be necessary to query the state of a background
+job. But access to these objects is provided for users who want to
+exercise even greater control over their use of background
+processes.
+
+Calls to C<Forks::Super::fork> that fail (return C<undef> or small negative
+numbers) generally do not cause a new C<Forks::Super::Job> instance
+to be created.
+
+=head1 ATTRIBUTES
+
+Use the C<Forks::Super::Job::get> or C<Forks::Super::Job::getByName>
+methods to obtain a Forks::Super::Job object for
+examination. The C<Forks::Super::Job::get> method takes a process ID or
+job ID as an input (a value that may have been returned from a previous
+call to C<Forks::Super::fork> and returns a reference to a C<Forks::Super::Job>
+object, or C<undef> if the process ID or job ID was not associated
+with any known Job object. The C<Forks::Super::Job::getByName> looks up
+job objects by the C<name> parameter that may have been passed
+in the C<Forks::Super::fork> call.
+
+A C<Forks::Super::Job> object has many attributes, some of which may
+be of interest to an end-user. Most of these should not be overwritten.
+
+=over 4
+
+=item pid
+
+Process ID or job ID. For deferred processes, this will be a 
+unique large negative number (a job ID). For processes that
+were not deferred, this valud is the process ID of the
+child process that performed this job's task.
+
+=item real_pid
+
+The process ID of the child process that performed this job's
+task. For deferred processes, this value is undefined until
+the job is launched and the child process is spawned.
+
+=item pgid
+
+The process group ID of the child process. For deferred processes,
+this value is undefined until the child process is spawned.
+
+=item created
+
+The time (since the epoch) at which the instance was created.
+
+=item start
+
+The time at which a child process was created for the job. This
+value will be undefined until the child process is spawned.
+
+=item end
+
+The time at which the child process completed and the parent
+process received a C<SIGCHLD> signal for the end of this process.
+This value will be undefined until the child process is complete.
+
+=item reaped
+
+The time at which a job was reaped via a call to
+C<Forks::Super::wait>, C<Forks::Super::waitpid>, or C<Forks::Super::waitall>. Will be
+undefined until the job is reaped.
+
+=item state
+
+A string value indicating the current state of the job.
+Current allowable values are
+
+=over 4
+
+=item C<DEFERRED>
+
+For jobs that are on the job queue and have not started yet.
+
+=item C<ACTIVE>
+
+For jobs that have started in a child process
+
+=item C<COMPLETE>
+
+For jobs that have completed and caused the parent process to
+receive a C<SIGCHLD> signal, but have not been reaped.
+
+=item C<REAPED>
+
+For jobs that have been reaped by a call to C<Forks::Super::wait>, 
+C<Forks::Super::waitpid>, or C<Forks::Super::waitall>.
+
+=item C<SUSPENDED>
+
+Reserved for future use.
+
+=back
+
+=item status
+
+The exit status of a job. See L<CHILD_ERROR|perlvar#CHILD_ERROR> in
+C<perlvar>. Will be undefined until the job is complete.
+
+=item style
+
+One of the strings C<natural>, C<cmd>, or C<sub>, indicating whether
+the initial C<fork> call returned from the child process or whether
+the child process was going to run a shell command or invoke a Perl
+subroutine and then exit.
+
+=item cmd
+
+The shell command to run that was supplied in the C<fork> call.
+
+=item sub
+
+=item args
+
+The name of or reference to CODE to run and the subroutine 
+arguments that were supplied in the C<fork> call.
+
+=item _on_busy
+
+The behavior of this job in the event that the system was
+too "busy" to enable the job to launch. Will have one of
+the string values C<block>, C<fail>, or C<queue>.
+
+=item queue_priority
+
+If this job was deferred, the relative priority of this 
+job.
+
+=item can_launch
+
+By default undefined, but could be a CODE reference
+supplied in the C<fork()> call. If defined, it is the
+code that runs when a job is ready to start to determine
+whether the system is too busy or not.
+
+=item depend_on
+
+If defined, contains a list of process IDs and job IDs that
+must B<complete> before this job will be allowed to start.
+
+=item depend_start
+
+If defined, contains a list of process IDs and job IDs that
+must B<start> before this job will be allowed to start.
+
+=item start_after
+
+Indicates the earliest time (since the epoch) at
+which this job may start.
+
+=item expiration
+
+Indicates the latest time that this job may be allowed to
+run. Jobs that run past their expiration parameter will
+be killed.
+
+=item os_priority
+
+Value supplied to the C<fork> call about desired 
+operating system priority for the job.
+
+=item cpu_affinity
+
+Value supplied to the C<fork> call about desired
+CPU's for this process to prefer.
+
+=back
+
+=head1 SEE ALSO
+
+C<< L<Forks::Super> >>.
+
+=head1 AUTHOR
+
+Marty O'Brien, E<lt>mob@cpan.orgE<gt>
+
+=head1 LICENSE AND COPYRIGHT
+
+Copyright (c) 2009-2010, Marty O'Brien.
+
+This program is free software; you can redistribute it and/or modify it
+under the same terms as Perl itself, either Perl version 5.8.8 or,
+at your option, any later version of Perl 5 you may have available. 
+
+=cut
